@@ -181,7 +181,7 @@ void FakeServer::readClientPart(QTcpSocket *socket, int *scenarioNumber)
         return;
     }
     QList<QByteArray> scenario = *it;
-    QVector<QByteArray> header;
+    QList<QByteArray> header;
 
     while (line != "\r\n") {
         header << line;
@@ -217,3 +217,5 @@ int FakeServer::port() const
 {
     return m_port;
 }
+
+#include "moc_fakeserver.cpp"
