@@ -300,14 +300,14 @@ void DavCollectionsFetchJobPrivate::collectionsFetchFinished(KJob *job)
                 QColor color;
                 if (!colorElement.isNull()) {
                     QString colorValue = colorElement.text();
-                    if (QColor::isValidColor(colorValue)) {
+                    if (QColor::isValidColorName(colorValue)) {
                         // Color is either #RRGGBBAA or #RRGGBB but QColor expects #AARRGGBB
                         // so we put the AA in front if the string's length is 9.
                         if (colorValue.size() == 9) {
                             QString fixedColorValue = QStringLiteral("#") + colorValue.mid(7, 2) + colorValue.mid(1, 6);
-                            color.setNamedColor(fixedColorValue);
+                            color = QColor::fromString(fixedColorValue);
                         } else {
-                            color.setNamedColor(colorValue);
+                            color = QColor::fromString(colorValue);
                         }
                     }
                 }
@@ -354,3 +354,5 @@ void DavCollectionsFetchJobPrivate::subjobFinished()
         emitResult();
     }
 }
+
+#include "moc_davcollectionsfetchjob.cpp"
